# Step 1: Understand Your Strategy
### On this page
  * [IT Strategy as the Basis for Application Rationalization](https://help.sap.com/docs/leanix/ea/application-rationalization-understand-strategy#it-strategy-as-the-basis-for-application-rationalization)
  * [Example](https://help.sap.com/docs/leanix/ea/application-rationalization-understand-strategy#example)


Aligning IT and business strategy in SAP LeanIX ensures application rationalization initiatives support enterprise architecture goals and deliver measurable outcomes.
